import { Config } from './types';
import { Path } from '../../types';
/**
 * Checks if the snyk policy file exists in the provided path
 * @param {string} policyPath - the path of the policy file.
 * @returns {[boolean, Object]} - snyk policy file is present or not and the error in case of failure
 */
export declare function exists(policyPath: string): boolean;
/**
 * Parses the snyk policy file content
 * @param {string} policyPath - the path of the policy file.
 * @returns {Object} - the content of the policy file
 */
export declare function parse(policyPath: string): Config;
/**
 * Resolves an array of paths relative to the basedir
 * @param {string} basedir - the basedir used for resolving the paths
 * @param {Array} paths - the paths to be resolved
 * @returns {Array} - the resolved paths
 */
export declare function toAbsolutePaths(basedir: string, paths?: readonly string[]): Path[];
/**
 * Resolves an array of paths relative to the basedir
 * @param {string} expires - date string
 * @returns {boolean} - whether or not the provided date has expired
 */
export declare function hasExpired(expires?: string | null): boolean;
